/*
	This file is part of lcl.

	lcl is free software: you can redistribute it and/or modify
	it under the terms of the GNU Lesser General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	lcl is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU Lesser General Public License for more details.

	You should have received a copy of the GNU Lesser General Public License
	along with lcl.  If not, see <http://www.gnu.org/licenses/>.

	Copyright (C) 2008 - 2009 Lucas Hermann Negri
*/

#ifndef LCL_LOCALE
#define LCL_LOCALE

#include "lcl.h"

enum Field
{
	CURRENCY_SYMBOL = 1, DECIMAL_POINT, FRAC_DIGITS, GROUPING, INT_CURR_SYMBOL,
	INT_FRAC_DIGITS, MON_DECIMAL_POINT,	MON_GROUPING, MON_THOUSANDS_SEP, NEGATIVE_SIGN,
	N_CS_PRECEDES, N_SEP_BY_SPACE, N_SIGN_POSN, POSITIVE_SIGN, P_CS_PRECEDES,
	P_SEP_BY_SPACE, P_SIGN_POSN, THOUSANDS_SEP
};

/**
 * Sets the current locale.
 * 
 * @param p1 Integer Fields to set (LC_ALL, LC_MONETARY, etc). Default: LC_ALL.
 * @param p2 String	 Locale name. Default: "".
 * @return String Locale name
 */
int lcl_set_locale(lua_State* L);

/**
 * Gets a field of the lconv struct.
 * 
 * @param p1 .. pN Integer Field(s) to get (like CURRENCY_SYMBOL)
 * @return String Value of the field(s) p1 .. pN
 */
int lcl_get_field(lua_State* L);

/**
 * Initializes the locale lconv to the default (doesn't load the system default).
 */
void init_locale();

/**
 * Compares two strings as if they where numbers, preserving precision (the only
 * limit to the precision is the memory).
 * It doesn't handles exponent notation (10E-5 for example) and it expects a 
 * valid number in any base that follows the ASCII characters precedence.
 * Its ~ 4 times faster than converting to a number and comparing the results.
 * 
 * @param s1 String 1
 * @param s2 String 2
 * @return 1, 0 or -1, if s1 is higher, equal or lower than s2
 */
int lcl_compare_string_as_number(lua_State* L);

#endif
